@@ -1,7 +1,6 @@
 """
 grdlandmask - Create a "wet-dry" mask grid from shoreline data base
 """
-
 from pygmt.clib import Session
 from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
@@ -13,6 +12,8 @@ from pygmt.helpers import (
 )
 from pygmt.io import load_dataarray
 
+__doctest_skip__ = ["grdlandmask"]
+
 
 @fmt_docstring
 @use_alias(
@@ -26,7 +27,7 @@ from pygmt.io import load_dataarray
     V="verbose",
     r="registration",
 )
-@kwargs_to_strings(R="sequence", N="sequence", E="sequence")
+@kwargs_to_strings(I="sequence", R="sequence", N="sequence", E="sequence")
 def grdlandmask(**kwargs):
     r"""
     Create a grid file with set values for land and water.
@@ -92,13 +93,20 @@ def grdlandmask(**kwargs):
         - :class:`xarray.DataArray` if ``outgrid`` is not set
         - None if ``outgrid`` is set (grid output will be stored in file set by
           ``outgrid``)
+
+    Example
+    -------
+    >>> import pygmt
+    >>> # Create a landmask grid with an x-range of 125 to 130,
+    >>> # and a y-range of 30 to 35
+    >>> landmask = pygmt.grdlandmask(spacing=1, region=[125, 130, 30, 35])
     """
-    if "I" not in kwargs.keys() or "R" not in kwargs.keys():
+    if "I" not in kwargs or "R" not in kwargs:
         raise GMTInvalidInput("Both 'region' and 'spacing' must be specified.")
 
     with GMTTempFile(suffix=".nc") as tmpfile:
         with Session() as lib:
-            if "G" not in kwargs.keys():  # if outgrid is unset, output to tempfile
+            if "G" not in kwargs:  # if outgrid is unset, output to tempfile
                 kwargs.update({"G": tmpfile.name})
             outgrid = kwargs["G"]
             arg_str = build_arg_string(kwargs)
