@@ -61,10 +61,10 @@ def grdview(self, grid, **kwargs):
         DataArray.
     region : str or list
         *xmin/xmax/ymin/ymax*\ [**+r**][**+u**\ *unit*].
-        Specify the :doc:`region </tutorials/regions>` of interest. When used
-        with ``perspective``, optionally append */zmin/zmax* to indicate the
-        range to use for the 3-D axes [Default is the region in the input
-        grid].
+        Specify the :doc:`region </tutorials/basics/regions>` of interest.
+        When used with ``perspective``, optionally append */zmin/zmax* to
+        indicate the range to use for the 3-D axes [Default is the region in
+        the input grid].
     {J}
     zscale/zsize : float or str
         Set z-axis scaling or z-axis size.
