@@ -149,9 +149,9 @@ def makecpt(**kwargs):
     with Session() as lib:
         if "W" in kwargs and "Ww" in kwargs:
             raise GMTInvalidInput("Set only categorical or cyclic to True, not both.")
-        if "H" not in kwargs.keys():  # if no output is set
+        if "H" not in kwargs:  # if no output is set
             arg_str = build_arg_string(kwargs)
-        elif "H" in kwargs.keys():  # if output is set
+        elif "H" in kwargs:  # if output is set
             outfile = kwargs.pop("H")
             if not outfile or not isinstance(outfile, str):
                 raise GMTInvalidInput("'output' should be a proper file name.")
