@@ -7,7 +7,6 @@ from pygmt.helpers import (
     build_arg_string,
     check_data_input_order,
     data_kind,
-    deprecate_parameter,
     fmt_docstring,
     is_nonstr_iter,
     kwargs_to_strings,
@@ -17,8 +16,6 @@ from pygmt.src.which import which
 
 
 @fmt_docstring
-@deprecate_parameter("columns", "incols", "v0.4.0", remove_version="v0.6.0")
-@deprecate_parameter("sizes", "size", "v0.4.0", remove_version="v0.6.0")
 @check_data_input_order("v0.5.0", remove_version="v0.7.0")
 @use_alias(
     A="straight_line",
@@ -199,15 +196,13 @@ def plot3d(
         and data.geom_type.isin(["Point", "MultiPoint"]).all()
     ):  # checking if the geometry of a geoDataFrame is Point or MultiPoint
         kwargs["S"] = "u0.2c"
-    elif (
-        "S" not in kwargs and kind == "file"
-    ):  # checking that the data is a file path to set default style
+    elif "S" not in kwargs and kind == "file" and data.endswith(".gmt"):
+        # checking that the data is a file path to set default style
         try:
             with open(which(data), mode="r", encoding="utf8") as file:
                 line = file.readline()
-            if (
-                "@GMULTIPOINT" in line or "@GPOINT" in line
-            ):  # if the file is gmt style and geometry is set to Point
+            if "@GMULTIPOINT" in line or "@GPOINT" in line:
+                # if the file is gmt style and geometry is set to Point
                 kwargs["S"] = "u0.2c"
         except FileNotFoundError:
             pass
