@@ -184,7 +184,7 @@ def text_(
         raise GMTInvalidInput("Must provide text with x/y pairs or position")
 
     # Build the -F option in gmt text.
-    if "F" not in kwargs.keys() and (
+    if "F" not in kwargs and (
         (
             position is not None
             or angle is not None
@@ -210,7 +210,7 @@ def text_(
         kwargs["F"] += f"+j{justify}"
 
     if isinstance(position, str):
-        kwargs["F"] += f'+c{position}+t"{text}"'
+        kwargs["F"] += f"+c{position}+t{text}"
 
     extra_arrays = []
     # If an array of transparency is given, GMT will read it from
