@@ -3,16 +3,17 @@ Tests for grdtrack.
 """
 import os
 
+import numpy as np
 import numpy.testing as npt
 import pandas as pd
 import pytest
-from pygmt import grdtrack, which
-from pygmt.datasets import load_earth_relief, load_ocean_ridge_points
+from pygmt import grdtrack
 from pygmt.exceptions import GMTInvalidInput
-from pygmt.helpers import data_kind
+from pygmt.helpers import GMTTempFile, data_kind
+from pygmt.helpers.testing import load_static_earth_relief
 
 TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), "data")
-TEMP_TRACK = os.path.join(TEST_DATA_DIR, "tmp_track.txt")
+POINTS_DATA = os.path.join(TEST_DATA_DIR, "track.txt")
 
 
 @pytest.fixture(scope="module", name="dataarray")
@@ -20,36 +21,40 @@ def fixture_dataarray():
     """
     Load the grid data from the sample earth_relief file.
     """
-    return load_earth_relief(registration="gridline").sel(
-        lat=slice(-49, -42), lon=slice(-118, -107)
-    )
+    return load_static_earth_relief()
+
+
+@pytest.fixture(scope="module", name="expected_array")
+def fixture_numpy_array():
+    """
+    Load a numpy array with x, y, and bathymetry data.
+    """
+    array = [
+        [-51.613, -17.93, 796.59434514],
+        [-48.917, -22.434, 566.49184359],
+        [-50.444, -16.358, 571.1492788],
+        [-50.721, -16.628, 578.76116859],
+        [-51.394, -12.196, 274.43205501],
+        [-50.207, -18.404, 532.11444935],
+        [-52.56, -16.977, 670.16934401],
+        [-51.866, -19.794, 426.77300768],
+        [-48.001, -14.144, 741.35824074],
+        [-54.438, -19.193, 490.02716679],
+    ]
+    return array
 
 
 @pytest.fixture(scope="module", name="dataframe")
 def fixture_dataframe():
     """
-    Load the ocean ridge file.
+    Load a pandas DataFrame with points.
     """
-    return load_ocean_ridge_points()
+    return pd.read_csv(
+        POINTS_DATA, sep=r"\s+", header=None, names=["longitude", "latitude"]
+    )
 
 
-@pytest.fixture(scope="module", name="csvfile")
-def fixture_csvfile():
-    """
-    Load the csvfile.
-    """
-    return which("@ridge.txt", download="c")
-
-
-@pytest.fixture(scope="module", name="ncfile")
-def fixture_ncfile():
-    """
-    Load the ncfile.
-    """
-    return which("@earth_relief_01d", download="a")
-
-
-def test_grdtrack_input_dataframe_and_dataarray(dataarray, dataframe):
+def test_grdtrack_input_dataframe_and_dataarray(dataarray, dataframe, expected_array):
     """
     Run grdtrack by passing in a pandas.DataFrame and xarray.DataArray as
     inputs.
@@ -57,56 +62,41 @@ def test_grdtrack_input_dataframe_and_dataarray(dataarray, dataframe):
     output = grdtrack(points=dataframe, grid=dataarray, newcolname="bathymetry")
     assert isinstance(output, pd.DataFrame)
     assert output.columns.to_list() == ["longitude", "latitude", "bathymetry"]
-    npt.assert_allclose(output.iloc[0], [-110.9536, -42.2489, -2790.488422])
-
-    return output
+    npt.assert_allclose(np.array(output), expected_array)
 
 
-def test_grdtrack_input_csvfile_and_dataarray(dataarray, csvfile):
+def test_grdtrack_input_csvfile_and_dataarray(dataarray, expected_array):
     """
     Run grdtrack by passing in a csvfile and xarray.DataArray as inputs.
     """
-    try:
-        output = grdtrack(points=csvfile, grid=dataarray, outfile=TEMP_TRACK)
+    with GMTTempFile() as tmpfile:
+        output = grdtrack(points=POINTS_DATA, grid=dataarray, outfile=tmpfile.name)
         assert output is None  # check that output is None since outfile is set
-        assert os.path.exists(path=TEMP_TRACK)  # check that outfile exists at path
-
-        track = pd.read_csv(TEMP_TRACK, sep="\t", header=None, comment=">")
-        npt.assert_allclose(track.iloc[0], [-110.9536, -42.2489, -2790.488422])
-    finally:
-        os.remove(path=TEMP_TRACK)
-
-    return output
+        assert os.path.exists(path=tmpfile.name)  # check that outfile exists at path
+        output = np.loadtxt(tmpfile.name)
+        npt.assert_allclose(np.array(output), expected_array)
 
 
-def test_grdtrack_input_dataframe_and_ncfile(dataframe, ncfile):
+def test_grdtrack_input_dataframe_and_ncfile(dataframe, expected_array):
     """
     Run grdtrack by passing in a pandas.DataFrame and netcdf file as inputs.
     """
-
-    output = grdtrack(points=dataframe, grid=ncfile, newcolname="bathymetry")
+    output = grdtrack(
+        points=dataframe, grid="@static_earth_relief.nc", newcolname="bathymetry"
+    )
     assert isinstance(output, pd.DataFrame)
     assert output.columns.to_list() == ["longitude", "latitude", "bathymetry"]
-    npt.assert_allclose(output.iloc[0], [-32.2971, 37.4118, -1939.748245])
-
-    return output
+    npt.assert_allclose(np.array(output), expected_array)
 
 
-def test_grdtrack_input_csvfile_and_ncfile(csvfile, ncfile):
+def test_grdtrack_input_csvfile_and_ncfile_to_dataframe(expected_array):
     """
-    Run grdtrack by passing in a csvfile and netcdf file as inputs.
+    Run grdtrack by passing in a csv file and netcdf file as inputs with a
+    pandas.DataFrame output.
     """
-    try:
-        output = grdtrack(points=csvfile, grid=ncfile, outfile=TEMP_TRACK)
-        assert output is None  # check that output is None since outfile is set
-        assert os.path.exists(path=TEMP_TRACK)  # check that outfile exists at path
-
-        track = pd.read_csv(TEMP_TRACK, sep="\t", header=None, comment=">")
-        npt.assert_allclose(track.iloc[0], [-32.2971, 37.4118, -1939.748245])
-    finally:
-        os.remove(path=TEMP_TRACK)
-
-    return output
+    output = grdtrack(points=POINTS_DATA, grid="@static_earth_relief.nc")
+    assert isinstance(output, pd.DataFrame)
+    npt.assert_allclose(np.array(output), expected_array)
 
 
 def test_grdtrack_wrong_kind_of_points_input(dataarray, dataframe):
@@ -141,11 +131,9 @@ def test_grdtrack_without_newcolname_setting(dataarray, dataframe):
         grdtrack(points=dataframe, grid=dataarray)
 
 
-def test_grdtrack_without_outfile_setting(csvfile, ncfile):
+def test_grdtrack_without_outfile_setting(dataarray, dataframe):
     """
     Run grdtrack by not passing in outfile parameter setting.
     """
-    output = grdtrack(points=csvfile, grid=ncfile)
-    npt.assert_allclose(output.iloc[0], [-32.2971, 37.4118, -1939.748245])
-
-    return output
+    with pytest.raises(GMTInvalidInput):
+        grdtrack(points=dataframe, grid=dataarray)
